import express from 'express'
import authCtrl from '../auth/auth.controller.js'
import userCtrl from '../user/user.controller.js'
import quizCtrl from './quiz.controller.js'

const router = express.Router()

router.route('/api/quiz/:userId')
  .post(authCtrl.requireSignin, authCtrl.hasAuthorization, userCtrl.isInstructor, quizCtrl.create)
  .get(authCtrl.requireSignin, authCtrl.hasAuthorization, quizCtrl.listByUserId)

router.route('/api/quiz/by/:quizId')
  .get(authCtrl.requireSignin, quizCtrl.isAuthor, quizCtrl.read)

router.route('/api/quiz/problem/:userId')
  .post(authCtrl.requireSignin, userCtrl.isInstructor)

router.route('/api/quiz/problem/by/:problemId')
  .get(authCtrl.requireSignin, quizCtrl.isProblemAuthor, quizCtrl.readProblem)
  .put(authCtrl.requireSignin, quizCtrl.isProblemAuthor, quizCtrl.updateProblem)
  .delete(authCtrl.requireSignin, quizCtrl.isProblemAuthor, quizCtrl.removeProblem)

router.param('userId', userCtrl.userById)
router.param('quizId', quizCtrl.quizById)
router.param('problemId', quizCtrl.problemById)

export default router